@@ -369,7 +369,10 @@ gtk_clutter_embed_unmap (GtkWidget *widget)
 {
   GtkClutterEmbedPrivate *priv = GTK_CLUTTER_EMBED (widget)->priv;
 
-  clutter_actor_unmap (priv->stage);
+  /* gtk may emit an unmap signal after dispose, so it's possible we may
+   * have already disposed priv->stage. */
+  if (priv->stage != NULL)
+    clutter_actor_unmap (priv->stage);
 
   GTK_WIDGET_CLASS (gtk_clutter_embed_parent_class)->unmap (widget);
 }
@@ -675,7 +678,7 @@ gtk_clutter_embed_new (void)
  * Retrieves the #ClutterStage from @embed. The returned stage can be
  * used to add actors to the Clutter scene.
  *
- * Return value: (transfer full): the Clutter stage. You should never
+ * Return value: (transfer none): the Clutter stage. You should never
  *   destroy or unref the returned actor.
  */
 ClutterActor *
